==> nextcloud-31.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/th.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "ไฟล์อัปโหลดแล้ว",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ขนาดไฟล์ที่อัปโหลดมีขนาดเกินค่า upload_max_filesize ที่ระบุไว้ใน php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ขนาดไฟล์ที่อัปโหลดมีขนาดเกินค่า MAX_FILE_SIZE ที่ระบุไว้ในรูปแบบของ HTML",
    "The file was only partially uploaded" : "ไฟล์ถูกอัปโหลดเพียงบางส่วน",
    "No file was uploaded" : "ไม่มีไฟล์ที่ถูกอัปโหลด",
    "Missing a temporary folder" : "โฟลเดอร์ชั่วคราวขาดหาย",
    "Could not write file to disk" : "ไม่สามารถเขียนไฟล์ลงดิสก์",
    "A PHP extension stopped the file upload" : "ส่วนขยาย PHP ได้หยุดการอัปโหลดไฟล์",
    "File not found" : "ไม่พบไฟล์",
    "Text" : "ข้อความ",
    "Translate" : "แปลภาษา",
    "Reload" : "โหลดใหม่",
    "guest" : "ผู้เยี่ยมชม",
    "Offline" : "ออฟไลน์",
    "Saving …" : "กำลังบันทึก …",
    "Saved" : "บันทึกแล้ว",
    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
    "Link" : "ลิงก์",
    "Undo" : "เลิกทำ",
    "Cannot copy, please copy the link manually" : "ไม่สามารถคัดลอก กรุณาคัดลอกลิงก์เอง",
    "Save changes" : "บันทึกการเปลี่ยนแปลง",
    "Cancel" : "ยกเลิก",
    "URL" : "URL",
    "to" : "ถึง",
    "Replace" : "แทนที่",
    "Edit" : "แก้ไข",
    "Source code" : "โค้ดต้นฉบับ",
    "Details" : "รายละเอียด",
    "Formatting" : "การจัดรูปแบบ",
    "Info" : "ข้อมูล",
    "Success" : "สำเร็จ",
    "Warning" : "คำเตือน"
},
"nplurals=1; plural=0;");

==> nextcloud-32.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/th.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "ไฟล์อัปโหลดแล้ว",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ขนาดไฟล์ที่อัปโหลดมีขนาดเกินค่า upload_max_filesize ที่ระบุไว้ใน php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ขนาดไฟล์ที่อัปโหลดมีขนาดเกินค่า MAX_FILE_SIZE ที่ระบุไว้ในรูปแบบของ HTML",
    "The file was only partially uploaded" : "ไฟล์ถูกอัปโหลดเพียงบางส่วน",
    "No file was uploaded" : "ไม่มีไฟล์ที่ถูกอัปโหลด",
    "Missing a temporary folder" : "โฟลเดอร์ชั่วคราวขาดหาย",
    "Could not write file to disk" : "ไม่สามารถเขียนไฟล์ลงดิสก์",
    "A PHP extension stopped the file upload" : "ส่วนขยาย PHP ได้หยุดการอัปโหลดไฟล์",
    "File not found" : "ไม่พบไฟล์",
    "Text" : "ข้อความ",
    "Reload" : "โหลดใหม่",
    "you" : "คุณ",
    "Copy link" : "คัดลอกลิงก์",
    "guest" : "ผู้เยี่ยมชม",
    "Offline" : "ออฟไลน์",
    "Saving …" : "กำลังบันทึก …",
    "Saved" : "บันทึกแล้ว",
    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
    "Link" : "ลิงก์",
    "Undo" : "เลิกทำ",
    "Save changes" : "บันทึกการเปลี่ยนแปลง",
    "Cancel" : "ยกเลิก",
    "URL" : "URL",
    "Save" : "บันทึก",
    "Translate" : "แปลภาษา",
    "to" : "ถึง",
    "Replace" : "แทนที่",
    "Upload" : "อัปโหลด",
    "Edit" : "แก้ไข",
    "Source code" : "โค้ดต้นฉบับ",
    "Details" : "รายละเอียด",
    "Formatting" : "การจัดรูปแบบ",
    "Choose" : "เลือก",
    "Choose {file}" : "เลือก {file}",
    "Cannot copy, please copy the link manually" : "ไม่สามารถคัดลอก กรุณาคัดลอกลิงก์เอง"
},
"nplurals=1; plural=0;");
